@@ -1,19 +1,20 @@
 DEFAULT = 'no_version'
 
 # Every loadmaster should have at least these capabilities
-BASE_CAPABILITIES = {
-    "reboot": {},
-    "stats": {},
-    "shutdown": {},
-    "backup": {},
-    "restore": {},
-}
+BASE_CAPABILITIES = [
+    "reboot",
+    "stats",
+    "shutdown",
+    "backup",
+    "restore",
+]
 
-LOADMASTER_CAPABILITIES = BASE_CAPABILITIES.update({
-    "templates": {},
-    "firmware": {},
-    "virtual_services": {},
-})
+LOADMASTER_CAPABILITIES = BASE_CAPABILITIES
+LOADMASTER_CAPABILITIES.extend([
+    "templates",
+    "firmware",
+    "virtual_services",
+])
 
 CAPABILITIES = {
     DEFAULT: BASE_CAPABILITIES,
