@@ -5,6 +5,7 @@ import logging
 import requests
 from requests import exceptions
 
+from python_kemptech_api import utils
 from python_kemptech_api.api_xml import (
     get_error_msg, is_successful,
     get_data_field, parse_to_dict,
@@ -34,9 +35,6 @@ from .utils import (
 requests.packages.urllib3.disable_warnings()
 log = logging.getLogger(__name__)
 
-tls_session = requests.Session()
-tls_session.mount("http://", UseTlsAdapter())
-
 
 class HttpClient(object):
     """Client that performs HTTP requests."""
@@ -44,6 +42,10 @@ class HttpClient(object):
     ip_address = None
     endpoint = None
 
+    def __init__(self, tls_version=utils.DEFAULT_TLS_VERSION):
+        self.tls_session = requests.Session()
+        self.tls_session.mount("http://", UseTlsAdapter(tls_version))
+
     def __enter__(self):
         return self
 
@@ -69,15 +71,16 @@ class HttpClient(object):
         try:
             if file is not None:
                 with open(file, 'rb') as payload:
-                    response = tls_session.request(http_method, cmd_url,
-                                                   params=parameters,
-                                                   verify=False, data=payload,
-                                                   headers=headers)
+                    response = self.tls_session.request(http_method, cmd_url,
+                                                        params=parameters,
+                                                        verify=False,
+                                                        data=payload,
+                                                        headers=headers)
             else:
-                response = tls_session.request(http_method, cmd_url,
-                                               params=parameters,
-                                               timeout=5, verify=False,
-                                               headers=headers)
+                response = self.tls_session.request(http_method, cmd_url,
+                                                    params=parameters,
+                                                    timeout=5, verify=False,
+                                                    headers=headers)
             if 400 < response.status_code < 500:
                 raise KempTechApiException(msg=response.text)
             else:
@@ -128,12 +131,14 @@ def send_response(response):
 class LoadMaster(HttpClient):
     """LoadMaster API object."""
 
-    def __init__(self, ip, username, password, port=443):
+    def __init__(self, ip, username, password, port=443,
+                 tls_version=utils.DEFAULT_TLS_VERSION):
         self.ip_address = ip
         self.username = username
         self.password = password
         self.port = port
         self.version = None
+        super(LoadMaster, self).__init__(tls_version)
 
     def __repr__(self):
         return '{}:{}'.format(self.ip_address, self.port)
@@ -335,7 +340,7 @@ class LoadMaster(HttpClient):
                                                            ip=self.ip_address,
                                                            port=self.port)
         try:
-            tls_session.get(url, verify=False, timeout=1)
+            self.tls_session.get(url, verify=False, timeout=1)
             return True
         except exceptions.RequestException:
             return False
