@@ -1,9 +1,9 @@
 try:
     from ssl import PROTOCOL_TLSv1_2
-    TLS_VERSION = PROTOCOL_TLSv1_2
+    DEFAULT_TLS_VERSION = PROTOCOL_TLSv1_2
 except ImportError:
     from ssl import PROTOCOL_TLSv1
-    TLS_VERSION = PROTOCOL_TLSv1
+    DEFAULT_TLS_VERSION = PROTOCOL_TLSv1
 
 import sys
 
@@ -15,6 +15,22 @@ from .exceptions import ValidationError
 
 IS_PY3 = sys.version[0] == '3'
 
+try:
+    from ssl import PROTOCOL_TLSv1
+    TSL_v1 = PROTOCOL_TLSv1
+except ImportError:
+    TSL_v1 = DEFAULT_TLS_VERSION
+try:
+    from ssl import PROTOCOL_TLSv1_1
+    TSL_v1_1 = PROTOCOL_TLSv1_1
+except ImportError:
+    TSL_v1_1 = DEFAULT_TLS_VERSION
+try:
+    from ssl import PROTOCOL_TLSv1_2
+    TSL_v1_2 = PROTOCOL_TLSv1_2
+except ImportError:
+    TSL_v1_2 = DEFAULT_TLS_VERSION
+
 
 def validate_port(port):
     try:
@@ -41,10 +57,14 @@ def validate_protocol(protocol):
 
 class UseTlsAdapter(HTTPAdapter):
 
+    def __init__(self, tls_version):
+        self.tls_version = tls_version
+        super(UseTlsAdapter, self).__init__()
+
     def init_poolmanager(self, connections, maxsize, block=False):
         self.poolmanager = PoolManager(num_pools=connections,
                                        maxsize=maxsize, block=block,
-                                       ssl_version=TLS_VERSION)
+                                       ssl_version=self.tls_version)
 
 
 def get_sub_vs_list_from_data(response_data):
